@@ -555,4 +555,16 @@ $(document).ready(function() {
       value();
     ok(returned == 6 && intercepted == 6, 'can use tapped objects in a chain');
   });
+
+  test("has", function () {
+     var obj = {foo: "bar", func: function () {} };
+     ok (_.has(obj, "foo"), "has() checks that the object has a property.");
+     ok (_.has(obj, "baz") == false, "has() returns false if the object doesn't have the property.");
+     ok (_.has(obj, "func"), "has() works for functions too.");
+     obj.hasOwnProperty = null;
+     ok (_.has(obj, "foo"), "has() works even when the hasOwnProperty method is deleted.");
+     var child = {};
+     child.prototype = obj;
+     ok (_.has(child, "foo") == false, "has() does not check the prototype chain for a property.")
+  });
 });
